.. currentmodule:: solposx


Code documentation
==================


Solar position algorithms
-------------------------
.. autosummary::
   :toctree: generated/

   solarposition.iqbal


Refraction correction algorithms
--------------------------------
.. autosummary::
   :toctree: generated/

   refraction.hughes
